@@ -591,7 +591,7 @@ emoji_pattern = re.compile("["
 
 def emo(text, emojiINtext = False):
     """
-    :smiling_face_with_smiling_eyes: : will be replace by , but _ stay 
+    :smiling_face_with_smiling_eyes: : will be replaced by , but _ stay 
     """
     #text = 'I love food 😊, ok👍👍 bad😱😱 or 🙂great🙂 🙂 💀 😂? '
     #text = 'how good food ❤️ strong❤️😊 recommendation.'
